<?php

namespace Litecms\Job\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Job\Models\Jobs;

class JobsPolicy
{

    /**
     * Determine if the given user can view the jobs.
     *
     * @param UserPolicy $user
     * @param Jobs $jobs
     *
     * @return bool
     */
    public function view(UserPolicy $user, Jobs $jobs)
    {
        if ($user->canDo('job.jobs.view') && $user->isAdmin()) {
            return true;
        }

        return $jobs->user_id == user_id() && $jobs->user_type == user_type();
    }

    /**
     * Determine if the given user can create a jobs.
     *
     * @param UserPolicy $user
     * @param Jobs $jobs
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('job.jobs.create');
    }

    /**
     * Determine if the given user can update the given jobs.
     *
     * @param UserPolicy $user
     * @param Jobs $jobs
     *
     * @return bool
     */
    public function update(UserPolicy $user, Jobs $jobs)
    {
        if ($user->canDo('job.jobs.edit') && $user->isAdmin()) {
            return true;
        }

        return $jobs->user_id == user_id() && $jobs->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given jobs.
     *
     * @param UserPolicy $user
     * @param Jobs $jobs
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Jobs $jobs)
    {
        return $jobs->user_id == user_id() && $jobs->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given jobs.
     *
     * @param UserPolicy $user
     * @param Jobs $jobs
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Jobs $jobs)
    {
        if ($user->canDo('job.jobs.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given jobs.
     *
     * @param UserPolicy $user
     * @param Jobs $jobs
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Jobs $jobs)
    {
        if ($user->canDo('job.jobs.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
